@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta;
 
-our $VERSION = '2.150011';
+our $VERSION = '2.150012';
 
 #pod =head1 SYNOPSIS
 #pod
@@ -649,7 +649,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.150011
+version 2.150012
 
 =head1 SYNOPSIS
 
@@ -1028,7 +1028,7 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =item *
 
